@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 2759 2007-12-16 10:45:35Z svn $
+ * $Id: UploadItem.h 2813 2008-03-07 14:35:04Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_H
@@ -41,7 +41,8 @@
 #include "Macro.h"
 
 #define AS_UITEM(pointer)           reinterpret_cast<UploadItem *>(pointer)
-
+#define AS_UITEM_H(pointer)         reinterpret_cast<UploadItem::header_t *>(pointer)
+#define AS_UITEM_H_VER2x(pointer)   reinterpret_cast<UploadItem::header_ver2x_t *>(pointer)
 
 /**
  * @brief アップロードアイテムを表すクラス．
@@ -86,6 +87,39 @@ public:
         }
     } header_t;
 
+    typedef struct header_ver2x {
+        char            identifier[ITM_MAX_IDENTIFIER_SIZE];
+        char            version[ITM_MAX_VERSION_SIZE];
+        apr_size_t      id;
+        apr_size_t      index;
+        apr_atomic_t    download_count;
+        union {
+            struct {
+                bool    is_gzipped      : 1;
+                bool    is_need_sync    : 1;
+            };
+            bool        flags;
+        };
+        apr_uint64_t    file_size;
+        apr_time_t      mtime;
+        char            date[ITM_MAX_DATE_SIZE];
+        char            ip_address[ITM_MAX_IP_ADDRESS_SIZE];
+        char            file_name[ITM_MAX_FILE_NAME_SIZE];
+        char            file_mime[ITM_MAX_FILE_MIME_SIZE];
+        char            file_ext[ITM_MAX_FILE_EXT_SIZE];
+        char            file_digest[ITM_MAX_FILE_DIGEST_SIZE];
+        char            remove_pass[ITM_MAX_REMOVE_PASS_SIZE];
+        char            download_pass[ITM_MAX_DOWNLOAD_PASS_SIZE];
+        char            comment[ITM_MAX_COMMENT_SIZE];
+
+        header_ver2x() {
+            memset(identifier, 0, sizeof(struct header));
+
+            strncpy(identifier, PACKAGE_NAME, ITM_MAX_IDENTIFIER_SIZE-1);
+            strncpy(version, PACKAGE_VERSION, ITM_MAX_VERSION_SIZE-1);
+        }
+    } header_ver2x_t;
+
     typedef int(*CompareFunc)(const UploadItem *a, const UploadItem *b);
 
     UploadItem();
