@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: Auxiliary.cpp 2880 2008-05-01 12:19:40Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2880 2008-05-01 12:19:40Z svn $");
 
 const char *rfc2396_encode(apr_pool_t *pool, const char* str)
 {
@@ -172,7 +172,7 @@ double get_usage_sec()
 
     getrusage(RUSAGE_SELF, &rusage);
 
-    return rusage.ru_utime.tv_sec + (double)rusage.ru_utime.tv_usec*(1e-6);
+    return (double)rusage.ru_utime.tv_sec + (double)rusage.ru_utime.tv_usec*(1e-6);
 }
 #endif
 
@@ -426,7 +426,7 @@ const char *strnchr(const char *s, size_t length, int c)
     count = static_cast<apr_size_t>(length);
 
     // ワード境界まではバイト単位でチェック．
-    tail_count = static_cast<apr_size_t>(reinterpret_cast<apr_uint64_t>(pos) &
+    tail_count = static_cast<apr_size_t>(reinterpret_cast<uintptr_t>(pos) &
                                          (sizeof(long)-1));
     if (tail_count) {
         tail_count = sizeof(long) - tail_count;
@@ -442,7 +442,7 @@ const char *strnchr(const char *s, size_t length, int c)
         }
     }
 
-    word_pos = reinterpret_cast<const unsigned long *>(pos);
+    word_pos = reinterpret_cast<const unsigned long *>(AVOID_ALIGN_WARN pos);
 
     if (sizeof(long) == 4) {
         magic = 0x7EFEFEFFL;
