@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DirectoryCleaner.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: DirectoryCleaner.cpp 2817 2008-03-14 15:52:31Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -37,7 +37,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DirectoryCleaner.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: DirectoryCleaner.cpp 2817 2008-03-14 15:52:31Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -68,7 +68,8 @@ void DirectoryCleaner::clean_old_files(apr_pool_t *pool,
                 continue;
             }
 
-            if ((current_time-info.mtime) < (threshold_sec*APR_USEC_PER_SEC)) {
+            if ((current_time-info.mtime) <
+                static_cast<apr_time_t>(threshold_sec*APR_USEC_PER_SEC)) {
                 continue;
             }
 
