@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageDigest5.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: MessageDigest5.cpp 2868 2008-04-24 15:02:00Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: MessageDigest5.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: MessageDigest5.cpp 2868 2008-04-24 15:02:00Z svn $");
 
 #ifdef DEBUG
 #define REQUIRE_UPDATE_STATE(state)                             \
@@ -216,10 +216,10 @@ void MessageDigest5::int2byte(const apr_uint32_t *ints, apr_size_t size,
                               apr_byte_t *bytes)
 {
     for (apr_size_t i = 0; i < size; i++) {
-        bytes[i*4    ] = (ints[i]      ) & 0xff;
-        bytes[i*4 + 1] = (ints[i] >>  8) & 0xff;
-        bytes[i*4 + 2] = (ints[i] >> 16) & 0xff;
-        bytes[i*4 + 3] = (ints[i] >> 24) & 0xff;
+        bytes[i*4    ] = (apr_byte_t)((ints[i]      ) & 0xff);
+        bytes[i*4 + 1] = (apr_byte_t)((ints[i] >>  8) & 0xff);
+        bytes[i*4 + 2] = (apr_byte_t)((ints[i] >> 16) & 0xff);
+        bytes[i*4 + 3] = (apr_byte_t)((ints[i] >> 24) & 0xff);
     }
 }
 
