@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MultipartMessageParser.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: MultipartMessageParser.cpp 2872 2008-04-27 14:18:02Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -125,7 +125,7 @@ MultipartMessageParser<R, W>::get_content(apr_array_header_t *content_array,
 {
     content_t *contents;
 
-    contents = AS_CONTENT(content_array->elts);
+    contents = AS_CONTENT(AVOID_ALIGN_WARN content_array->elts);
     for (int i = 0; i < content_array->nelts; i++) {
         if (strncmp((contents + i)->name, name, strlen(name)) == 0) {
             return contents + i;
@@ -143,7 +143,7 @@ MultipartMessageParser<R, W>::get_text_content(apr_array_header_t *content_array
     content_t *contents;
     apr_size_t count;
 
-    contents = AS_CONTENT(content_array->elts);
+    contents = AS_CONTENT(AVOID_ALIGN_WARN content_array->elts);
     count = 0;
     for (int i = 0; i < content_array->nelts; i++) {
         if ((contents + i)->type == TEXT) {
@@ -164,7 +164,7 @@ MultipartMessageParser<R, W>::get_file_content(apr_array_header_t *content_array
     content_t *contents;
     apr_size_t count;
 
-    contents = AS_CONTENT(content_array->elts);
+    contents = AS_CONTENT(AVOID_ALIGN_WARN content_array->elts);
     count = 0;
     for (int i = 0; i < content_array->nelts; i++) {
         if ((contents + i)->type == FILE) {
@@ -184,7 +184,7 @@ void MultipartMessageParser<R, W>::dump_content_array(apr_array_header_t *conten
 
     cout << "****************************************" << endl;
 
-    contents = AS_CONTENT(content_array->elts);
+    contents = AS_CONTENT(AVOID_ALIGN_WARN content_array->elts);
     for (int i = 0; i < content_array->nelts; i++) {
         dump_content(contents + i);
         cout << "****************************************" << endl;
