@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: TemplateLexer.cpp 2872 2008-04-27 14:18:02Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: TemplateLexer.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateLexer.cpp 2872 2008-04-27 14:18:02Z svn $");
 
 #define AS_TOKEN(pointer)           reinterpret_cast<token_t *>(pointer)
 #define AS_TOKEN_P(pointer)         reinterpret_cast<token_t **>(pointer)
@@ -191,7 +191,7 @@ void TemplateLexer::dump_token_array(apr_array_header_t *token_array,
     int i;
     token_t **tokens;
 
-    tokens = AS_TOKEN_P(token_array->elts);
+    tokens = AS_TOKEN_P(AVOID_ALIGN_WARN token_array->elts);
     for (i = 0; i < token_array->nelts; i++) {
         dump_token(tokens[i], id_array);
     }
@@ -526,7 +526,7 @@ apr_size_t TemplateLexer::get_id(const char *str, apr_size_t length)
     const char **ids;
     int i;
 
-    ids = AS_CONST_CHAR_P(id_array_->elts);
+    ids = AS_CONST_CHAR_P(AVOID_ALIGN_WARN id_array_->elts);
     for (i = 0; i < id_array_->nelts; i++) {
         if (strncmp(ids[i], str, max(strlen(ids[i]), length)) == 0) {
             return i;
@@ -601,7 +601,7 @@ void TemplateLexer::dump_token(const token_t *token,
     cerr << setw(10) << setfill(' ') << get_token_type(token) << ": ";
 
     if (token->type == TemplateLexer::IDENTIFIER) {
-        cerr << AS_CONST_CHAR_P(id_array->elts)[token->id];
+        cerr << AS_CONST_CHAR_P(AVOID_ALIGN_WARN id_array->elts)[token->id];
         cerr << '(' << token->id << ')';
     } else if (token->type == TemplateLexer::STRING) {
         TemporaryPool temp_pool;
