@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateParser.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: TemplateParser.cpp 2872 2008-04-27 14:18:02Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -37,7 +37,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: TemplateParser.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateParser.cpp 2872 2008-04-27 14:18:02Z svn $");
 
 #define AS_NODE(pointer)            reinterpret_cast<node_t *>(pointer)
 #define AS_UNCONST_NODE(pointer)    const_cast<node_t *>(pointer)
@@ -156,8 +156,8 @@ const TemplateParser::node_t *TemplateParser::parse(apr_pool_t *pool,
     TemplateParser parser(pool, node_memory, lexer);
     parser.parse();
 
-    *ids = AS_CONST_CHAR_P(lexer->get_id_array()->elts);
-    *keys = AS_CONST_CHAR_P(parser.get_key_array()->elts);
+    *ids = AS_CONST_CHAR_P(AVOID_ALIGN_WARN lexer->get_id_array()->elts);
+    *keys = AS_CONST_CHAR_P(AVOID_ALIGN_WARN parser.get_key_array()->elts);
 
     return parser.get_node_tree();
 }
@@ -913,7 +913,7 @@ TemplateParser::node_t *TemplateParser::parse_variable()
     input_.top++;
 
     node = parse_variable_();
-    
+
     if (node  == NULL) {
         node = child_node;
     } else {
@@ -947,7 +947,8 @@ TemplateParser::node_t *TemplateParser::parse_variable_()
 
         child_node = create_node(KEY);
         child_node->id
-            = get_key(AS_CONST_CHAR_P(id_array_->elts)[(*(input_.top))->id]);
+            = get_key(AS_CONST_CHAR_P(AVOID_ALIGN_WARN id_array_->elts)
+                      [(*(input_.top))->id]);
         node->child.right = child_node;
         input_.top++;
     } else if ((*(input_.top))->type == Lexer::BRACKET_LEFT) { // '[' (INTEGER | IDENTIFIER) ']' VARIABLE__
@@ -1007,7 +1008,8 @@ TemplateParser::node_t *TemplateParser::parse_variable__()
 
     child_node = create_node(KEY);
     child_node->id
-        = get_key(AS_CONST_CHAR_P(id_array_->elts)[(*(input_.top))->id]);
+        = get_key(AS_CONST_CHAR_P(AVOID_ALIGN_WARN id_array_->elts)
+                  [(*(input_.top))->id]);
     node->child.right = child_node;
 
     input_.top++;
@@ -1020,7 +1022,7 @@ apr_size_t TemplateParser::get_key(const char *str)
     const char **keys;
     int i;
 
-    keys = AS_CONST_CHAR_P(key_array_->elts);
+    keys = AS_CONST_CHAR_P(AVOID_ALIGN_WARN key_array_->elts);
     for (i = 0; i < key_array_->nelts; i++) {
         if (strcmp(keys[i], str) == 0) {
             return i;
