@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemListReader.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: UploadItemListReader.cpp 2872 2008-04-27 14:18:02Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2872 2008-04-27 14:18:02Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -114,7 +114,7 @@ void UploadItemListReader::get_subdir_threads(apr_pool_t *pool,
     apr_dir_t *sub_dir;
     apr_finfo_t file_info;
     TemporaryPool temp_pool(pool);
-    char buffer[sizeof(UploadItem)];
+    long buffer[PAD_DIV(sizeof(UploadItem), sizeof(long))];
     UploadItem *uitem = AS_UITEM(buffer);
 
     if (apr_dir_open(&sub_dir, sub_dir_path, temp_pool.get()) != APR_SUCCESS) {
