@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: mod_uploader.cpp 2882 2008-05-02 12:28:05Z svn $
  *****************************************************************************/
 
 /**
@@ -30,6 +30,10 @@
  * @brief Apache モジュールのエントリ関数群．
  */
 
+#ifndef __STDC_CONSTANT_MACROS
+#define __STDC_CONSTANT_MACROS
+#endif
+
 // Apache の config.h を先に処理させるため，httpd.h のインクルードはこの位置
 #include "httpd.h"
 
@@ -61,7 +65,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2882 2008-05-02 12:28:05Z svn $");
 
 static const char *HANDLER_NAME = "uploader";
 static apr_array_header_t *uploader_config_array = NULL;
@@ -213,7 +217,7 @@ static bool get_apache_debug_mode()
 {
     const char **defs;
 
-    defs = AS_CONST_CHAR_P(ap_server_config_defines->elts);
+    defs = AS_CONST_CHAR_P(AVOID_ALIGN_WARN ap_server_config_defines->elts);
 
     for (int i = 0; i < ap_server_config_defines->nelts; i++) {
         // -X オプション付きで起動されたときは DEBUG が定義されている
@@ -231,7 +235,7 @@ static int uploader_post_config_server(apr_pool_t *p, server_rec *s)
     UploaderConfig **configs;
     UploaderConfig *config;
 
-    configs = (UploaderConfig **)uploader_config_array->elts;
+    configs = (UploaderConfig **)AVOID_ALIGN_WARN uploader_config_array->elts;
 
     for (int i = 0; i < uploader_config_array->nelts; i++) {
         config = configs[i];
@@ -295,7 +299,7 @@ static void uploader_child_init_server(apr_pool_t *pool, server_rec *s)
     UploaderConfig **configs;
     UploaderConfig *config;
 
-    configs = (UploaderConfig **)uploader_config_array->elts;
+    configs = (UploaderConfig **)AVOID_ALIGN_WARN uploader_config_array->elts;
 
     for (int i = 0; i < uploader_config_array->nelts; i++) {
         config = configs[i];
