@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2852 2008-04-11 15:56:37Z svn $
+ * $Id: uploader_handler.cpp 2880 2008-05-01 12:19:40Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2852 2008-04-11 15:56:37Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2880 2008-05-01 12:19:40Z svn $");
 #endif
 
 #define STR_CMP_LITERAL(arg, literal)                            \
@@ -437,7 +437,7 @@ static int info(typename Response::Handle *r, UploaderConfig *config,
         apr_uint32_t upload_id;
         RequestReader::post_progress_t *progress;
 
-        upload_id = static_cast<apr_size_t>
+        upload_id = static_cast<apr_uint32_t>
             (apr_atoi64(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])));
         progress = config->get_post_progress_list()->get(upload_id);
 
