@@ -45,7 +45,7 @@ run cp src/mod_uploader-ap2.2.so ${WEB_BASE}/file
 )
 
 (
-    run rsync -av --max-size=400000 . ${CVS_BASE}
+    run rsync -avLq --exclude '.*' --max-size=400K . ${CVS_BASE}
     run cd ${CVS_BASE}
     cvs commit -m ""
     run cvs tag release-${VERSION}_`date "+%y%m%d%H%M"`
