@@ -29,12 +29,27 @@ if ($args{'mode'} eq 'release') {
 } else {
     my @links = $sf->get_release_links();
     my $src_link = (grep($_->text() =~ /^mod_uploader-.*\.tgz$/, @links))[0];
+    my $rpm_link = (grep($_->text() =~ /^mod_uploader-.*\.x86_64\.rpm$/, @links))[0];
+    my $srpm_link = (grep($_->text() =~ /^mod_uploader-.*\.src\.rpm$/, @links))[0];
+    my $deb_link = (grep($_->text() =~ /^libapache2-mod-uploader_.*\.deb$/, @links))[0];
     my $win32_bin_link = (grep($_->text() =~ /^mod_uploader-.*\.msi$/, @links))[0];
 
     while (<>) {
         if (/\* `mod_uploader-\d+\.\d+\.\d+\.tgz/) {
             print << "__HTML__";
 * `@{[$src_link->text()]}[0] <@{[$src_link->url()]}[0]>`_
+__HTML__
+        } elsif (/\* `mod_uploader-\d+\.\d+\.\d+-1\.x86_64\.rpm/) {
+            print << "__HTML__";
+* `@{[$rpm_link->text()]}[0] <@{[$rpm_link->url()]}[0]>`_  (for CentOS, FedoraCore 64bit)
+__HTML__
+        } elsif (/\* `mod_uploader-\d+\.\d+\.\d+-1\.src\.rpm/) {
+            print << "__HTML__";
+* `@{[$srpm_link->text()]}[0] <@{[$srpm_link->url()]}[0]>`_  (for CentOS, FedoraCore)
+__HTML__
+        } elsif (/\* `libapache2-mod-uploader_\d+\.\d+\.\d+-1_amd64\.deb/) {
+            print << "__HTML__";
+* `@{[$deb_link->text()]}[0] <@{[$deb_link->url()]}[0]>`_  (for Debian, Ubuntu 64bit)
 __HTML__
         } elsif (/\* `mod_uploader-\d+\.\d+\.\d+\.msi/) {
             print << "__HTML__";
