@@ -68,32 +68,32 @@ sub mount_disk {
 
     $exp->send('net use ' . DISK_DEVICE . ' ' . quotemeta(DISK_PATH) .
                ' /USER:' . $user . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, '$ ');
+    $exp->expect(CMD_TIMEOUT_SEC, '$');
 }
 
 sub init_tree {
     my $exp = shift;
 
     $exp->send('base_dir=`mktemp -d $TEMP/mod_uploader.XXXXXX`' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, '$ ');
+    $exp->expect(CMD_TIMEOUT_SEC, '$');
 
     $exp->send('cp -pr ' . MOD_UPLOADER_PATH . '/work/mod_uploader/* ' .
                '$base_dir' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, '$ ');
+    $exp->expect(CMD_TIMEOUT_SEC, '$');
 }
 
 sub cd_src_dir {
     my $exp = shift;
 
     $exp->send('cd $base_dir/src' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, '$ ');
+    $exp->expect(CMD_TIMEOUT_SEC, '$');
 }
 
 sub cd_util_dir {
     my $exp = shift;
 
     $exp->send('cd $base_dir/util' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, '$ ');
+    $exp->expect(CMD_TIMEOUT_SEC, '$');
 }
 
 sub set_module_env {
@@ -110,7 +110,7 @@ sub exit_cmd {
     my $exp = shift;
 
     $exp->send('exit' . "\n");
-    $exp->expect(MAKE_TIMEOUT_SEC, '$ ');
+    $exp->expect(MAKE_TIMEOUT_SEC, '$');
 }
 
 sub compile_module {
@@ -157,9 +157,18 @@ sub copy_binary {
     my $exp = shift;
 
     $exp->send('cp -f $base_dir/*.msi ' . MOD_UPLOADER_PATH . '/' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, '$ ');
+    $exp->expect(CMD_TIMEOUT_SEC, '$');
     $exp->send('cp -f $base_dir/src/*.so ' . MOD_UPLOADER_PATH . '/src/' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, '$ ');
+    $exp->expect(CMD_TIMEOUT_SEC, '$');
+}
+
+sub clean_tree {
+    my $exp = shift;
+
+    $exp->send('cd $base_dir/..' . "\n");
+    $exp->expect(CMD_TIMEOUT_SEC, '$');
+    $exp->send('rm -rf $base_dir' . "\n");
+    $exp->expect(CMD_TIMEOUT_SEC, '$');
 }
 
 my $user = $ENV{'USER'};
@@ -174,9 +183,9 @@ chomp($temp_dir);
 # ԡƤ饳ѥԤ
 
 # ĥ꡼ν
-`rm -rf work; ln -s $temp_dir work`;
-`svn export . work/mod_uploader`;
-`cd work/mod_uploader; ./configure --enable-thumbnail`;
+system("rm -rf work; ln -s $temp_dir work");
+system("svn export . work/mod_uploader");
+system("cd work/mod_uploader; ./configure --enable-thumbnail");
 
 # 
 ssh_login($exp, $pass);
@@ -204,8 +213,10 @@ exit_cmd($exp);
 
 # ХʥեΥԡ
 copy_binary($exp);
+# ĥ꡼κ
+clean_tree($exp);
 
-`rm -rf work $temp_dir`;
+system("rm -rf work $temp_dir");
 
 # Local Variables:
 # mode: cperl
